==> libgal-0.2.0.tar.gz: libgal-0.2.0/math/gal_factorial_test.c <==
/*  
 *  - - - - - - - - - - - - - - - - - - -  
 *   g a l _ f a c t o r i a l _ t e s t  
 *  - - - - - - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_factorial routine.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Called:
 *  
 *     gal_factorial  
 *     gal_vdv  
 *  
 *  This Revision:
 *  
 *     2008 March 22 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 */  
  
#include "gal_factorial_test.h"
#include "gal_factorial.h"
#include "gal_test.h"
  
void  
gal_factorial_test  
 (  
 ) 
 
{

  extern int gal_tfunc ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
  gal_vdv ( gal_factorial ( 0 ) ,   1.0, 0.0, "gal_factorial", "a 0" ) ;  
  gal_vdv ( gal_factorial (-2 ) ,  -1.0, 0.0, "gal_factorial", "a 1" ) ;  
  gal_vdv ( gal_factorial ( 1 ) ,   1.0, 0.0, "gal_factorial", "a 2" ) ;  
  gal_vdv ( gal_factorial ( 2 ) ,   2.0, 0.0, "gal_factorial", "a 3" ) ;  
  gal_vdv ( gal_factorial ( 3 ) ,   6.0, 0.0, "gal_factorial", "a 4" ) ;  
  gal_vdv ( gal_factorial ( 4 ) ,  24.0, 0.0, "gal_factorial", "a 5" ) ;  
  
  gal_tfunc++ ;  
  
/*  
 * Finished.  
 */  

}
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */

==> libgal-0.3.0.tar.gz: libgal-0.3.0/math/gal_factorial_test.c <==
/*  
 *  - - - - - - - - - - - - - - - - - - -  
 *   g a l _ f a c t o r i a l _ t e s t  
 *  - - - - - - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_factorial routine.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Called:
 *  
 *     gal_factorial  
 *     gal_vdv  
 *  
 *  This Revision:
 *  
 *     2008 June 14 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 */  
  
#include "gal_factorial_test.h"
#include "gal_factorial.h"
#include "gal_test.h"
  
void  
gal_factorial_test  
 (  
 ) 
 
{

  extern int gal_tfunc ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
  gal_vldv ( gal_factorial ( 0 ) ,   1.0, 0.0, "gal_factorial", "a 0" ) ;  
  gal_vldv ( gal_factorial (-2 ) ,  -1.0, 0.0, "gal_factorial", "a 1" ) ;  
  gal_vldv ( gal_factorial ( 1 ) ,   1.0, 0.0, "gal_factorial", "a 2" ) ;  
  gal_vldv ( gal_factorial ( 2 ) ,   2.0, 0.0, "gal_factorial", "a 3" ) ;  
  gal_vldv ( gal_factorial ( 3 ) ,   6.0, 0.0, "gal_factorial", "a 4" ) ;  
  gal_vldv ( gal_factorial ( 4 ) ,  24.0, 0.0, "gal_factorial", "a 5" ) ;  
  
  gal_tfunc++ ;  
  
/*  
 * Finished.  
 */  

}
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */
